@@ -1,4 +1,4 @@
-import maths
+from maths import maths
 class billpy:
     def findtax(percent,netamount):
         taxamount=maths.mul(netamount,maths.div(percent,100))
